@@ -25,8 +25,8 @@ def test_ref_calib():
         "magnet": "up",
         "bin_vars": '{"P": "P", "ETA": "ETA", "nTracks": "nTracks"}',
         "histo_dir": str(Path(THIS_DIR, "test_data")),
-        "output_dir": str(Path(THIS_DIR, "test_data")),
-        "dry_run": True,
+        "output_file": str(Path(THIS_DIR, "test_data/test_data_PIDCalibResults.root")),
+        "merge": False,
         "ref_file": str(Path(THIS_DIR, "test_data/ref_test_data.root")),
         "ref_tree": "DecayTree",
         "ref_pars": '{"Bach": ["K", "DLLK > 4"]}',
@@ -35,16 +35,18 @@ def test_ref_calib():
 
     with pytest.warns(RuntimeWarning):
         assert ref_calib.ref_calib(config) == pytest.approx(0.8745793984247746)
-    assert Path(THIS_DIR, "test_data/ref_test_data_PIDCalibResults.root").exists()
-    os.remove(Path(THIS_DIR, "test_data/ref_test_data_PIDCalibResults.root"))
+    assert Path(THIS_DIR, "test_data/test_data_PIDCalibResults.root").exists()
+    os.remove(Path(THIS_DIR, "test_data/test_data_PIDCalibResults.root"))
 
     with pytest.raises(SyntaxError):
         config = {
             "sample": "Turbo18",
             "magnet": "up",
             "bin_vars": '{"P", "ETA", "nTracks"}',
-            "output_dir": str(Path(THIS_DIR, "test_data")),
-            "dry_run": True,
+            "output_file": str(
+                Path(THIS_DIR, "test_data/test_data_PIDCalibResults.root")
+            ),
+            "merge": False,
             "ref_file": str(Path(THIS_DIR, "test_data/ref_test_data.root")),
             "ref_tree": "DecayTree",
             "ref_pars": '{"Bach": ["K", "DLLK > 4"]}',
@@ -57,8 +59,10 @@ def test_ref_calib():
             "sample": "Turbo18",
             "magnet": "up",
             "bin_vars": '{"P": "P", "ETA": "ETA", "nTracks": "nTracks"}',
-            "output_dir": str(Path(THIS_DIR, "test_data")),
-            "dry_run": True,
+            "output_file": str(
+                Path(THIS_DIR, "test_data/test_data_PIDCalibResults.root")
+            ),
+            "merge": False,
             "ref_file": str(Path(THIS_DIR, "test_data/ref_test_data.root")),
             "ref_tree": "DecayTree",
             "ref_pars": '{"Bach"}',
